@@ -1,11 +1,15 @@
-from pymwalib.correlator_context import CorrelatorContext
-import pytest
-import numpy as np
 from os.path import join as path_join, dirname
 
+import numpy as np
+import pytest
+
+from pymwalib.correlator_context import CorrelatorContext
+
+
 def prefix_test_data(path):
     return path_join(dirname(__file__), "data", path)
 
+
 @pytest.fixture
 def mwax_corr_context() -> CorrelatorContext:
     return CorrelatorContext(
@@ -21,11 +25,13 @@ def mwax_corr_context() -> CorrelatorContext:
         ))
     )
 
+
 def test_mwax_antennas(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.metafits_context.antennas) == 2
     assert mwax_corr_context.metafits_context.antennas[0].tile_id == 51
     assert mwax_corr_context.metafits_context.antennas[1].tile_id == 52
 
+
 def test_baselines(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.metafits_context.baselines) == 3
     assert mwax_corr_context.metafits_context.baselines[0].ant1_index == 0
@@ -35,6 +41,7 @@ def test_baselines(mwax_corr_context: CorrelatorContext):
     assert mwax_corr_context.metafits_context.baselines[2].ant1_index == 1
     assert mwax_corr_context.metafits_context.baselines[2].ant2_index == 1
 
+
 def test_mwax_rfinputs(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.metafits_context.rf_inputs) == 4
     assert mwax_corr_context.metafits_context.rf_inputs[0].tile_id == 51
@@ -46,6 +53,7 @@ def test_mwax_rfinputs(mwax_corr_context: CorrelatorContext):
     assert mwax_corr_context.metafits_context.rf_inputs[3].tile_id == 52
     assert mwax_corr_context.metafits_context.rf_inputs[3].pol == "Y"
 
+
 def test_mwax_coarse_channels(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.coarse_channels) == 2
     assert mwax_corr_context.coarse_channels[0].rec_chan_number == 117
@@ -58,6 +66,7 @@ def test_mwax_coarse_channels(mwax_corr_context: CorrelatorContext):
     assert mwax_corr_context.coarse_channels[0].corr_chan_number == 0
     assert mwax_corr_context.coarse_channels[1].corr_chan_number == 1
 
+
 def test_mwax_timesteps(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.timesteps) == 592
     assert mwax_corr_context.timesteps[0].unix_time_ms == 1613491214000
@@ -65,6 +74,7 @@ def test_mwax_timesteps(mwax_corr_context: CorrelatorContext):
     assert mwax_corr_context.timesteps[590].unix_time_ms == 1613491509000
     assert mwax_corr_context.timesteps[591].unix_time_ms == 1613491509500
 
+
 def test_read_by_baseline(mwax_corr_context: CorrelatorContext):
     ts = 0
     chan = 0
@@ -82,17 +92,20 @@ def test_read_by_baseline(mwax_corr_context: CorrelatorContext):
     print(f"\nCorrelator Sum by baseline  == {sum_bl}")
     print(f"Correlator Sum by frequency == {sum_f}")
 
+
 def test_common_timestep_indices(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.common_timestep_indices) == mwax_corr_context.num_common_timesteps
     assert len(mwax_corr_context.common_timestep_indices) == 2
     assert mwax_corr_context.common_timestep_indices[0] == 0
     assert mwax_corr_context.common_timestep_indices[1] == 1
 
+
 def test_common_good_timestep_indices(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.common_good_timestep_indices) == mwax_corr_context.num_common_good_timesteps
     assert len(mwax_corr_context.common_good_timestep_indices) == 1
     assert mwax_corr_context.common_good_timestep_indices[0] == 1
 
+
 def test_provided_timestep_indices(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.provided_timestep_indices) == mwax_corr_context.num_provided_timesteps
     assert len(mwax_corr_context.provided_timestep_indices) == 4
@@ -101,20 +114,40 @@ def test_provided_timestep_indices(mwax_corr_context: CorrelatorContext):
     assert mwax_corr_context.provided_timestep_indices[2] == 160
     assert mwax_corr_context.provided_timestep_indices[3] == 161
 
+
 def test_common_coarse_chan_indices(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.common_coarse_chan_indices) == mwax_corr_context.num_common_coarse_chans
     assert len(mwax_corr_context.common_coarse_chan_indices) == 2
     assert mwax_corr_context.common_coarse_chan_indices[0] == 0
     assert mwax_corr_context.common_coarse_chan_indices[1] == 1
 
+
 def test_common_good_coarse_chan_indices(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.common_good_coarse_chan_indices) == mwax_corr_context.num_common_good_coarse_chans
     assert len(mwax_corr_context.common_good_coarse_chan_indices) == 2
     assert mwax_corr_context.common_good_coarse_chan_indices[0] == 0
     assert mwax_corr_context.common_good_coarse_chan_indices[1] == 1
 
+
 def test_provided_coarse_chan_indices(mwax_corr_context: CorrelatorContext):
     assert len(mwax_corr_context.provided_coarse_chan_indices) == mwax_corr_context.num_provided_coarse_chans
     assert len(mwax_corr_context.provided_coarse_chan_indices) == 2
     assert mwax_corr_context.provided_coarse_chan_indices[0] == 0
     assert mwax_corr_context.provided_coarse_chan_indices[1] == 1
+
+
+def test_metafits_fine_chan_freqs_hz(mwax_corr_context: CorrelatorContext):
+    assert len(mwax_corr_context.metafits_context.metafits_fine_chan_freqs_hz) == \
+           mwax_corr_context.metafits_context.num_metafits_fine_chan_freqs
+    assert mwax_corr_context.metafits_context.metafits_fine_chan_freqs_hz[0] == 149120000.0
+    assert mwax_corr_context.metafits_context.metafits_fine_chan_freqs_hz[1] == 149760000.0
+    assert mwax_corr_context.metafits_context.metafits_fine_chan_freqs_hz[2] == 150400000.0
+    assert mwax_corr_context.metafits_context.metafits_fine_chan_freqs_hz[3] == 151040000.0
+
+
+def test_corr_get_fine_chan_freqs_hz_array(mwax_corr_context: CorrelatorContext):
+    # Get the fine channel frequencies for the first coarse channel
+    freq_list = mwax_corr_context.get_fine_chan_freqs_hz_array([0, ])
+    assert len(freq_list) == 2
+    assert freq_list[0] == 149120000.0
+    assert freq_list[1] == 149760000.0
